@@ -1,6 +1,6 @@
 <?php
 /*
- * $Id: comment_functions.php,v 1.1 2003/08/29 13:15:39 wellwine Exp $
+ * $Id: comment_functions.php,v 1.1 2003/06/30 15:22:40 wellwine Exp $
  * Copyright (c) 2003 by Jeremy N. Cowgar <jc@cowgar.com>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -23,13 +23,13 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
  */
 
-function blogger_com_update($link_id, $total_num){
+function weblog_com_update($link_id, $total_num){
   $db =& Database::getInstance();
   $sql = 'UPDATE '.$db->prefix('weblog').' SET comments = '.$total_num.' WHERE blog_id = '.$link_id;
   $db->query($sql);
 }
 
-function blogger_com_approve(&$comment){
+function weblog_com_approve(&$comment){
   // send notification mail
 }
 ?>
